# deCONZ
Python library wrapping [deCONZ rest api](https://dresden-elektronik.github.io/deconz-rest-doc/) for Home-Assistant.

This implementation should cover most devices supported by deCONZ, if that is not the case please create an issue with debug logs and we will get it supported.

Only host address and API key are necessary for normal operations.

## Acknowledgements
* Mattias Flodins custom deCONZ component was a great source of inspiration.
* Maija Vilkina and her blog [Snillevilla](https://snillevilla.se/) has been a huge help in getting deCONZ up and running.
* Thanks to donnib, dkmh, simonporter007, kroimon, Henrik Nilsson for requesting and verifying functionality!
* Special thanks to Dresden Elektronik for sponsoring with extra Conbee and Raspbee hardware.
